/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<notifyaccessor.h>)
#  include <notifyaccessor.h>
#endif
#if __has_include(<notifymodel.h>)
#  include <notifymodel.h>
#endif
#if __has_include(<notifystagingmodel.h>)
#  include <notifystagingmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_deepin_ds_notificationcenter()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<notifycenter::NotifyAccessor>("org.deepin.ds.notificationcenter", 1);
    qmlRegisterTypesAndRevisions<notifycenter::NotifyModel>("org.deepin.ds.notificationcenter", 1);
    qmlRegisterTypesAndRevisions<notifycenter::NotifyStagingModel>("org.deepin.ds.notificationcenter", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.deepin.ds.notificationcenter", 1, 0);
}

static const QQmlModuleRegistration orgdeepindsnotificationcenterRegistration("org.deepin.ds.notificationcenter", qml_register_types_org_deepin_ds_notificationcenter);
